ck_humidex: Humidex

View source: R/comfort.R

ck_humidexR Documentation

Humidex

Description

Compute the Canadian humidex from temperature and dewpoint.

Usage

ck_humidex(tavg, dewpoint)

Arguments

tavg

Numeric vector of temperatures (degrees C).

dewpoint

Numeric vector of dewpoint temperatures (degrees C).

Value

A data frame with columns value, index, and unit.

References

Masterson, J., & Richardson, F. A. (1979). Humidex: A method of quantifying human discomfort due to excessive heat and humidity. Environment Canada.

Examples

ck_humidex(tavg = c(30, 35), dewpoint = c(20, 25))

climatekit documentation built on May 9, 2026, 5:08 p.m.