| ck_summer_days | R Documentation |
Count the number of days where maximum temperature exceeds 25 degrees C.
ck_summer_days(tmax, dates, period = "annual")
tmax |
Numeric vector of daily maximum temperatures (degrees C). |
dates |
Date vector of the same length as |
period |
Character. Aggregation period: |
A data frame with columns period, value, index, and unit.
dates <- as.Date("2024-07-01") + 0:9
tmax <- c(22, 26, 28, 24, 30, 25, 27, 23, 31, 29)
ck_summer_days(tmax, dates)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.