ck_txn: Annual or Monthly Minimum of Daily Maximum Temperature (TXn)

View source: R/temperature.R

ck_txnR Documentation

Annual or Monthly Minimum of Daily Maximum Temperature (TXn)

Description

ETCCDI canonical index TXn. The minimum value of daily maximum temperature (Tmax) within each reporting period (coldest day).

Usage

ck_txn(tmax, dates, period = "annual")

Arguments

tmax

Numeric vector of daily maximum temperatures (degrees C).

dates

Date vector of the same length as tmax.

period

Character. Aggregation period: "annual" (default) or "monthly".

Value

A data frame with columns period, value, index, and unit.

Examples

dates <- as.Date("2024-01-01") + 0:9
tmax <- c(5, 10, -3, 12, 4, 8, 22, -8, 7, 6)
ck_txn(tmax, dates)

climatekit documentation built on May 9, 2026, 5:08 p.m.