ck_wind_chill: Wind Chill Temperature

View source: R/comfort.R

ck_wind_chillR Documentation

Wind Chill Temperature

Description

Compute wind chill using the North American Wind Chill Index formula (Environment Canada / US NWS). Valid for temperatures at or below 10 degrees C and wind speeds above 4.8 km/h.

Usage

ck_wind_chill(tavg, wind_speed)

Arguments

tavg

Numeric vector of temperatures (degrees C).

wind_speed

Numeric vector of wind speeds (km/h).

Value

A data frame with columns value, index, and unit.

Examples

ck_wind_chill(tavg = c(-5, -10, 0), wind_speed = c(20, 30, 15))

climatekit documentation built on May 9, 2026, 5:08 p.m.