| ck_heat_index | R Documentation |
Compute the heat index (apparent temperature) using the Rothfusz regression equation used by the US National Weather Service.
ck_heat_index(tavg, humidity)
tavg |
Numeric vector of temperatures (degrees C). |
humidity |
Numeric vector of relative humidity (percent, 0-100). |
A data frame with columns value, index, and unit.
Rothfusz, L. P. (1990). The heat index equation. NWS Technical Attachment SR 90-23.
ck_heat_index(tavg = c(30, 35, 40), humidity = c(60, 70, 50))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.