| ck_humidex | R Documentation |
Compute the Canadian humidex from temperature and dewpoint.
ck_humidex(tavg, dewpoint)
tavg |
Numeric vector of temperatures (degrees C). |
dewpoint |
Numeric vector of dewpoint temperatures (degrees C). |
A data frame with columns value, index, and unit.
Masterson, J., & Richardson, F. A. (1979). Humidex: A method of quantifying human discomfort due to excessive heat and humidity. Environment Canada.
ck_humidex(tavg = c(30, 35), dewpoint = c(20, 25))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.