| ck_ice_days | R Documentation |
Count the number of days where maximum temperature is below 0 degrees C.
ck_ice_days(tmax, dates, period = "annual")
tmax |
Numeric vector of daily maximum temperatures (degrees C). |
dates |
Date vector of the same length as |
period |
Character. Aggregation period: |
A data frame with columns period, value, index, and unit.
dates <- as.Date("2024-01-01") + 0:9
tmax <- c(-2, 3, -1, 5, -3, 0, 2, -4, 1, -1)
ck_ice_days(tmax, dates)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.