| ck_pet | R Documentation |
Estimate daily PET using the Hargreaves-Samani equation, which requires only daily temperature extremes and latitude.
ck_pet(tmin, tmax, lat, dates)
tmin |
Numeric vector of daily minimum temperatures (degrees C). |
tmax |
Numeric vector of daily maximum temperatures (degrees C). |
lat |
Numeric. Latitude in decimal degrees. |
dates |
Date vector of the same length as |
A data frame with columns date, value, index, and unit.
Hargreaves, G. H., & Samani, Z. A. (1985). Reference crop evapotranspiration from temperature. Applied Engineering in Agriculture, 1(2), 96-99.
dates <- as.Date("2024-07-01") + 0:9
tmin <- c(15, 16, 14, 17, 15, 13, 16, 14, 15, 16)
tmax <- c(30, 32, 28, 33, 31, 27, 34, 29, 30, 32)
ck_pet(tmin, tmax, lat = 45, dates = dates)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.