| ck_tropical_nights | R Documentation |
Count the number of days where minimum temperature exceeds 20 degrees C.
ck_tropical_nights(tmin, dates, period = "annual")
tmin |
Numeric vector of daily minimum temperatures (degrees C). |
dates |
Date vector of the same length as |
period |
Character. Aggregation period: |
A data frame with columns period, value, index, and unit.
dates <- as.Date("2024-07-01") + 0:9
tmin <- c(18, 21, 22, 19, 25, 20, 23, 17, 24, 21)
ck_tropical_nights(tmin, dates)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.