View source: R/precipitation.R
| ck_very_heavy_precip | R Documentation |
Count of days with precipitation at or above a threshold (default 20 mm).
ck_very_heavy_precip(precip, dates, threshold = 20, period = "annual")
precip |
Numeric vector of daily precipitation (mm). |
dates |
Date vector of the same length as |
threshold |
Numeric. Threshold in mm (default 20). |
period |
Character. Aggregation period: |
A data frame with columns period, value, index, and unit.
dates <- as.Date("2024-01-01") + 0:9
precip <- c(0, 5, 22, 0, 15, 25, 0, 11, 4, 30)
ck_very_heavy_precip(precip, dates)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.