View source: R/precipitation.R
| ck_wet_days | R Documentation |
Maximum number of consecutive days with precipitation at or above a threshold.
ck_wet_days(precip, dates, threshold = 1, period = "annual")
precip |
Numeric vector of daily precipitation (mm). |
dates |
Date vector of the same length as |
threshold |
Numeric. Wet day threshold in mm (default 1). |
period |
Character. Aggregation period: |
A data frame with columns period, value, index, and unit.
dates <- as.Date("2024-01-01") + 0:9
precip <- c(5, 3, 0, 2, 8, 1, 0, 0, 4, 6)
ck_wet_days(precip, dates)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.