| ck_wind_chill | R Documentation |
Compute wind chill using the North American Wind Chill Index formula (Environment Canada / US NWS). Valid for temperatures at or below 10 degrees C and wind speeds above 4.8 km/h.
ck_wind_chill(tavg, wind_speed)
tavg |
Numeric vector of temperatures (degrees C). |
wind_speed |
Numeric vector of wind speeds (km/h). |
A data frame with columns value, index, and unit.
ck_wind_chill(tavg = c(-5, -10, 0), wind_speed = c(20, 30, 15))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.