| ck_winkler | R Documentation |
The Winkler index (also called growing degree days for viticulture) accumulates daily mean temperature above 10 degrees C during the growing season (April-October in NH, October-April in SH).
ck_winkler(tavg, dates)
tavg |
Numeric vector of daily average temperatures (degrees C). |
dates |
Date vector of the same length as |
A data frame with columns period, value, index, and unit.
Amerine, M. A., & Winkler, A. J. (1944). Composition and quality of musts and wines of California grapes.
dates <- seq(as.Date("2024-04-01"), as.Date("2024-10-31"), by = "day")
set.seed(42)
tavg <- rnorm(length(dates), mean = 18, sd = 4)
ck_winkler(tavg, dates)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.